summaryrefslogtreecommitdiffstats
path: root/perl-install/ugtk2.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/ugtk2.pm')
-rw-r--r--perl-install/ugtk2.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/ugtk2.pm b/perl-install/ugtk2.pm
index 3db9ff814..931f377a7 100644
--- a/perl-install/ugtk2.pm
+++ b/perl-install/ugtk2.pm
@@ -1467,8 +1467,8 @@ sub new {
my $d_width = $darea->allocation->width;
my $x_blue = $is_rtl ? $d_width - $blue_width : 0;
my $x_icon = $is_rtl ? $d_width - 12 - $width : 12;
- # here: 48 is the amount of white background in the blue background we wish to ignore:
- my $x_text = $is_rtl ? $d_width - $blue_width + 48 - $darea->{txt_width} : $blue_width - 48;
+ # here: 10 is the amount of padding (white background) wish to add betwen text & blue background:
+ my $x_text = $is_rtl ? $d_width - $blue_width - 10 - $darea->{txt_width} : $blue_width + 10;
$darea->{layout_height} ||= second($darea->{layout}->get_pixel_size);
$blue_part->render_to_drawable($darea->window, $style->bg_gc('normal'),
0, 0, $x_blue, 0, -1, -1, 'none', 0, 0);